==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Round/ts/Round_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Round</name>
    <message>
        <location filename="../Round.js" line="+58"/>
        <source>The two entities cannot be rounded.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Te dwa podmioty nie mogą być zaokrąglone.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>First entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy podmiot nie może być przycięte.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Second entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Druga jednostka nie może być przycięte.</translation>
    </message>
    <message>
        <location filename="../Round.ui" line="+17"/>
        <source>Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz pierwszy obiekt do przycięcia
Zaznacz drugi obiekt do przycięcia</translatorcomment>
        <translation type="unfinished">Przytnij</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation type="unfinished">Promień:</translation>
    </message>
    <message>
        <location filename="../RoundInit.js" line="+2"/>
        <source>&amp;Round</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zaokrąglaj</translatorcomment>
        <translation type="unfinished">&amp;Zaokrąglaj</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Round/ts/Round_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Round</name>
    <message>
        <location filename="../Round.js" line="+58"/>
        <source>The two entities cannot be rounded.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można zaokrąglić wskazanych obiektów.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>First entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można przyciąć pierwszego obiektu.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Second entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można przyciąć drugiego obiektu.</translation>
    </message>
    <message>
        <location filename="../Round.ui" line="+17"/>
        <source>Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz pierwszy obiekt do przycięcia
Zaznacz drugi obiekt do przycięcia</translatorcomment>
        <translation>Przycięcie</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation>Promień:</translation>
    </message>
    <message>
        <location filename="../RoundInit.js" line="+2"/>
        <source>&amp;Round</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zaokrąglaj</translatorcomment>
        <translation>&amp;Zaokrąglij</translation>
    </message>
</context>
</TS>
